H5DJ
====

HDF5-based _n_-dimensional array tools 'n' types for Django
-----------------------------------------------------------

At the time of writing, this package contains:

* `HDF5Storage` -- A `django.core.files.storage.Storage` subclass, enabling easy persistent `ndarray` storage

... which that is it for the time being.

